﻿using Syncfusion.ListView.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;
using Xamarin.Forms;
using Xamarin.Forms.Internals;

namespace SfListViewSamples
{
    [Preserve(AllMembers = true)]
    class ViewModel : INotifyPropertyChanged
    {
        #region Fields

        private ObservableCollection<MessageInfo> messageInfo;
        private string newText;
        internal Syncfusion.ListView.XForms.SfListView ListView;
        private ImageSource sendIcon;

        #endregion

        #region Properties
        public ObservableCollection<MessageInfo> MessageInfo
        {
            get { return messageInfo; }
            set { this.messageInfo = value; }
        }

        public string NewText
        {
            get { return newText; }
            set
            {
                newText = value;
                OnPropertyChanged("NewText");
            }
        }

        public ImageSource SendIcon
        {
            get
            { return sendIcon; }
            set
            { sendIcon = value; }
        }

        public ICommand SendCommand { get; set; }
        public ICommand ButtonCommand { get; set; }

        private bool isLoading = false;

        public bool IsLoading
        {
            get { return isLoading; }
            set
            {
                this.isLoading = value;
                OnPropertyChanged("IsLoading");
            }
        }


        #endregion

        #region Interface

        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged(string propertyName = "")
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion Interface

        #region Constructor
        public ViewModel()
        {
            InitializeSendCommand();
            GenerateSource();
        }

        #endregion

        #region GenerateSource
        public void GenerateSource()
        {
            MessageInfoRepository Message = new MessageInfoRepository();
            MessageInfo = Message.GenerateInfo();
            ButtonCommand = new Command(ButtonTapped);
        }

        private void ButtonTapped(object obj)
        {
            Application.Current.MainPage.DisplayAlert("Message", "ImageButtontapped", "Ok");
        }

        #endregion

        #region InitializeCommand
        private void InitializeSendCommand()
        {
            Random r = new Random();
            Assembly assembly = typeof(DataTemplateSelector).GetTypeInfo().Assembly;
            SendIcon = ImageSource.FromResource("SfListViewSamples.Images.DTS.SendIcon.png", assembly);
            NewText = "";
            SendCommand = new Command(() =>
            {
                if (!string.IsNullOrWhiteSpace(NewText))
                {
                    MessageInfo.Add(new MessageInfo
                    {
                        OutgoingMessageIndicator = ImageSource.FromResource("SfListViewSamples.Images.DTS.OutgoingIndicatorImage.png", assembly),
                        Text = NewText,
                        TemplateType = this.Templatetypes[r.Next(0,2)],
                        DateTime = string.Format("{0:HH:mm}", DateTime.Now)
                    });
                    (ListView.LayoutManager as LinearLayout).ScrollToRowIndex(MessageInfo.Count - 1, Syncfusion.ListView.XForms.ScrollToPosition.Start);
                }
                NewText = null;
            });
        }
        
        public TemplateType[] Templatetypes = new TemplateType[]
       {
            TemplateType.OutGoingText,
            TemplateType.IncomingText,
            TemplateType.IncomingImage
       };

        #endregion
    }
}
